@@ -386,6 +386,23 @@ CLOUDFORMATION_ACTIONS_ONLY_ACCEPTS_WILDCARD = [
     "iam:SetSecurityTokenServicePreferences",
     "iam:SimulateCustomPolicy",
     "iam:UpdateAccountPasswordPolicy",
+    "iot:CreateCertificateFromCsr",
+    "iot:CreateKeysAndCertificate",
+    "iot:CreatePolicy",
+    "iot:DeleteRegistrationCode",
+    "iot:DescribeEndpoint",
+    "iot:GetLoggingOptions",
+    "iot:GetRegistrationCode",
+    "iot:ListCACertificates",
+    "iot:ListCertificates",
+    "iot:ListCertificatesByCA",
+    "iot:ListOutgoingCertificates",
+    "iot:ListPolicies",
+    "iot:ListThingTypes",
+    "iot:ListThings",
+    "iot:ListTopicRules",
+    "iot:RegisterCACertificate",
+    "iot:RegisterCertificate",
     "lambda:CreateEventSourceMapping",
     "lambda:GetAccountSettings",
     "lambda:ListEventSourceMappings",
@@ -475,4 +492,24 @@ CLOUDFORMATION_ACTIONS_ONLY_ACCEPTS_WILDCARD = [
     "s3:ListAllMyBuckets",
     "s3:ListJobs",
     "s3:PutAccountPublicAccessBlock",
+    "sns:CheckIfPhoneNumberIsOptedOut",
+    "sns:CreatePlatformApplication",
+    "sns:CreatePlatformEndpoint",
+    "sns:DeleteEndpoint",
+    "sns:DeletePlatformApplication",
+    "sns:GetEndpointAttributes",
+    "sns:GetPlatformApplicationAttributes",
+    "sns:GetSMSAttributes",
+    "sns:GetSubscriptionAttributes",
+    "sns:ListEndpointsByPlatformApplication",
+    "sns:ListPhoneNumbersOptedOut",
+    "sns:ListPlatformApplications",
+    "sns:ListSubscriptions",
+    "sns:ListTopics",
+    "sns:OptInPhoneNumber",
+    "sns:SetEndpointAttributes",
+    "sns:SetPlatformApplicationAttributes",
+    "sns:SetSMSAttributes",
+    "sns:SetSubscriptionAttributes",
+    "sns:Unsubscribe",
 ]
